@@ -49,8 +49,8 @@ sub _validation {
   my $self = shift;
 
   my $v = $self->validation;
-  $v->required('title');
-  $v->required('body');
+  $v->required('title', 'not_empty');
+  $v->required('body',  'not_empty');
 
   return $v;
 }
